@@ -18,11 +18,11 @@ our @EXPORT_OK = qw(
 	modelsdir
 ); # symbols to export on request (WHY?)
 
-our $VERSION = '0.4';
+our $VERSION = '0.5';
 
 
 BEGIN {
-    $VERSION = '0.4';
+    $VERSION = '0.5';
     if ($] > 5.006) {
         require XSLoader;
         XSLoader::load(__PACKAGE__, $VERSION);
@@ -91,7 +91,7 @@ Image::DecodeQR::WeChat - Decode QR code(s) from images using the OpenCV/WeChat
 
 =head1 VERSION
 
-Version 0.4
+Version 0.5
 
 
 =head1 SYNOPSIS
@@ -217,13 +217,13 @@ interface other parts of the OpenCV library:
 
 =over
 
-=item C<decode()>
+=item * C<decode()>
 
-=item C<decode_xs()>
+=item * C<decode_xs()>
 
-=item C<modelsdir()>
+=item * C<modelsdir()>
 
-=item C<opencv_has_highgui_xs()>
+=item * C<opencv_has_highgui_xs()>
 
 =back
 
@@ -254,16 +254,16 @@ It returns an empty ARRAYref (i.e. a ref to an empty array)
 if no QR codes were found or decoded successfully.
 
 These are the parameters it requires. They must all be present, with
-optinal parameters allowed to be C<undef>:
+optional parameters allowed to be C<undef>:
 
 
 =over
 
-=item C<infile> : the input image with zero or more QR codes.
+=item * C<infile> : the input image with zero or more QR codes.
 All the image formats of OpenCV's L<imread()|https://docs.opencv.org/4.5.5/d4/da8/group__imgcodecs.html>
 are supported.
 
-=item C<modelsdir> : the location of the directory holding all model files (CNN trained models)
+=item * C<modelsdir> : the location of the directory holding all model files (CNN trained models)
 required for QR code detection. These models are already included with this package and will be
 installed in a shared dir during installation. Their total size is about 1MB.
 They have been kindly contributed by WeChat along with their library for QR Code detection.
@@ -272,7 +272,7 @@ models location is returned by L<modelsdir()>. If you do not want to experiment
 your own models then just plug the output of L<modelsdir()> to this parameter, else
 specify your own.
 
-=item C<outbase> : optionally specify output files basename which will contain
+=item * C<outbase> : optionally specify output files basename which will contain
 detected QR-codes' payloads, bounding boxes and QR-code images extracted from
 the input image (one set of files for each QR-code detected).
 If C<dumpqrimagestofile> is set to 1 all the aforementioned files will
@@ -281,12 +281,14 @@ file (all in one file). If C<outbase> is left C<undef> then nothing is written t
 a file. As usual all detected codes' data is returned back via the returned
 value of L<decode_xs()>.
 
-=item C< verbosity > levels: 0 is mute, 1 is only for C code, 10 is for C+XS code.
+=item * C< verbosity > levels: 0 is mute, 1 is only for C code, 10 is for C+XS code.
 
-=item C< graphicaldisplayresult> : if set to 1, it will display a window with the input image
-and the detected QR-code(s) outlined.
+=item * C< graphicaldisplayresult> : if set to 1, it will display a window with the input image
+and the detected QR-code(s) outlined. This
+is subject to whether current OpenCV installation was compiled to support
+C< imshow() > (with C < highgui > enabled).
 
-=item C<dumpqrimagestofile> : if set to 0, and C<outbase> is specified, then all payloads
+=item * C<dumpqrimagestofile> : if set to 0, and C<outbase> is specified, then all payloads
 are written to a single file using the basename specified. If set to 1 a lot more information
 is written to separate files, one for each detected code. This is mainly for debugging purposes
 because the returned value contains the payloads and their corresponding QR-codes' bounding
@@ -310,26 +312,28 @@ The C< params > hashref:
 
 =over
 
-=item C<input> : the name of the input image file which can contain one or more QR codes.
+=item * C<input> : the name of the input image file which can contain one or more QR codes.
 
-=item C<outbase> : optional, if specified payloads (QR-code text) will be dumped to a text file.
+=item * C<outbase> : optional, if specified payloads (QR-code text) will be dumped to a text file.
 If further, C<dumpqrimagestofile> is set to 1 then image files with the detected QR-codes will
 be dumped one for each QR-code as well as text files with payloads and bounding boxes wrt the
 input imaghe.
 
-=item C<modelsdir> : optional, use it only if you want to use your own model files (for their
+=item * C<modelsdir> : optional, use it only if you want to use your own model files (for their
 format have a look at L<https://docs.opencv.org/4.x/d5/d04/classcv_1_1wechat__qrcode_1_1WeChatQRCode.html>, they are CNN training files).
 This package has included the model files kindly submitted by WeChat as a contribution to OpenCV
 and will be installed in your system with all other files. Use C<modelsdir()> to see the location
 of installed model files. Their total size is about 1MB.
 
-=item C<verbosity> : default is 0 which is muted. 1 is for verbose C code and 10 is for verbose C and XS code.
+=item * C<verbosity> : default is 0 which is muted. 1 is for verbose C code and 10 is for verbose C and XS code.
 
-=item C<dumpqrimagestofile> : default is 0, set to 1 to have lots of image and text files dumped (relative to C<outbase>)
+=item * C<dumpqrimagestofile> : default is 0, set to 1 to have lots of image and text files dumped (relative to C<outbase>)
 for each QR code detected.
 
-=item C<graphicaldisplayresult> : default is 0, set to 1 to have a window popping up with the input image
-and the QR-code detected highlighted, once for each code detected.
+=item * C<graphicaldisplayresult> : default is 0, set to 1 to have a window popping up with the input image
+and the QR-code detected highlighted, once for each code detected. This
+is subject to whether current OpenCV installation was compiled to support
+C< imshow() > (with C < highgui > enabled).
 
 =back
 
@@ -421,30 +425,30 @@ OpenCV from sources. This is the procedure I followed:
 
 =over
 
-=item Download OpenCV sources and also its contributed modules.
+=item 1. Download OpenCV sources and also its contributed modules.
 
-=item Extract the sources and change to the source dir.
+=item 2. Extract the sources and change to the source dir.
 
-=item From within the source dir extract the contrib archive.
+=item 3. From within the source dir extract the contrib archive.
 
-=item Create a C<build> dir and change to it.
+=item 4. Create a C<build> dir and change to it.
 
-=item There are two ways to make C<cmake> just tolerable:
+=item 5. There are two ways to make C<cmake> just tolerable:
 C<cmake-gui> and C<ccmake>. The former is a full-gui interface
 to setting the billion C<cmake> variables. Use it
 if you are on a machine which offers a GUI: C<cmake-gui ..>
- . If you are on a headless or remote host possibly over telnet or ssh
+If you are on a headless or remote host possibly over telnet or ssh
 then do not despair because c<ccmake> is the CLI, curses-based
 equivalent to C<cmake-gui>,  use it like: C<ccmake ..> (from within the build dir).
 
-=item Once on either of the cmake GUIs, first do a
+=item 6. Once on either of the cmake GUIs, first do a
 C<configure>, then check the
 list of all variables (you can search on both, for searching
 in the CLI, press C<</>> and then C<n> for next hit)
 to suit you and then C<generate>, quit
 and  C<VERBOSE=1 make -j4 all>
 
-=item I guess, cmake variables you want to modify
+=item 7. I guess, cmake variables you want to modify
 are C<OPENCV_EXTRA_MODULES_PATH>
 and C<OPENCV_ENABLE_NONFREE> and anything that has to do with C<CNN> or C<DNN>.
 If you have CUDA installed and a CUDA-capable GPU then enable CUDA
@@ -452,22 +456,21 @@ If you have CUDA installed and a CUDA-capable GPU then enable CUDA
 Eigen3, Intel's TBB, CNN, DNN etc. You need to install all these
 additional packages to get OpenCV support with them.
 
-=item I had a problem with compiling OpenCV with a GUI (the C<highgui>)
+=item 8. I had a problem with compiling OpenCV with a GUI (the C<highgui>)
 on a headless host. So, I just disabled it. That's easy to achieve
 during the above.
 
-=item I have both installed this on a CUDA-capable GPU (with CUDA 10.2 installed)
+=item 9. I have both installed this on a CUDA-capable GPU (with CUDA 10.2 installed)
 host and on a headless remote host with no GPU or basic. CUDA is
 not required for building this module.
 
+=back
+
 Your mileage may vary.
 
 If you are seriously in need of installing
 this module then consider migrating to a serious operating system
-such as Linux first. M$-Windows will always present problems and
-I don't have the patience of keeping track of them ...
-
-=back
+such as Linux as your first action.
 
 
 =head1 AUTHOR
@@ -511,19 +514,19 @@ L<https://metacpan.org/release/Image-DecodeQR-WeChat>
 
 =over
 
-=item The great Open Source L<OpenCV|https://opencv.org/>
+=item * The great Open Source L<OpenCV|https://opencv.org/>
 image processing library
 and its contributed module
 L<WeChat QRDetector|https://docs.opencv.org/4.x/dd/d63/group__wechat__qrcode.html>
 which form the backbone of this module and do all the heavy lifting.
 
-=item Botje and xenu at #perl for help.
+=item * Botje and xenu at #perl for help.
 
-=item Jiro Nishiguchi (L<JIRO | https://metacpan.org/author/JIRO>) whose
+=item * Jiro Nishiguchi (L<JIRO | https://metacpan.org/author/JIRO>) whose
 (obsolete with modern - at the time of writing - OpenCV)
 module L<Image::DecodeQR> serves as the skeleton for this module.
 
-=item Thank you! to all those who responded to this SO question L<https://stackoverflow.com/questions/71402095/perl-xs-create-and-return-array-of-strings-char-taken-from-calling-a-c-funct>
+=item * Thank you! to all those who responded to this SO question L<https://stackoverflow.com/questions/71402095/perl-xs-create-and-return-array-of-strings-char-taken-from-calling-a-c-funct>
 
 =back
 
